@@ -1,3 +1,7 @@
+from __future__ import annotations
+
+from typing import Any
+
 from .prettytable import (
     ALL,
     DEFAULT,
@@ -10,6 +14,7 @@ from .prettytable import (
     ORGMODE,
     PLAIN_COLUMNS,
     RANDOM,
+    SINGLE_BORDER,
     PrettyTable,
     TableHandler,
     from_csv,
@@ -23,6 +28,7 @@ __all__ = [
     "ALL",
     "DEFAULT",
     "DOUBLE_BORDER",
+    "SINGLE_BORDER",
     "FRAME",
     "HEADER",
     "MARKDOWN",
@@ -40,11 +46,12 @@ __all__ = [
     "from_json",
 ]
 
-try:
-    # Python 3.8+
-    import importlib.metadata as importlib_metadata
-except ImportError:
-    # <Python 3.7 and lower
-    import importlib_metadata
 
-__version__ = importlib_metadata.version(__name__)
+def __getattr__(name: str) -> Any:
+    if name == "__version__":
+        import importlib.metadata
+
+        return importlib.metadata.version(__name__)
+
+    msg = f"module '{__name__}' has no attribute '{name}'"
+    raise AttributeError(msg)
